import axios from 'axios'
import { HTTP_ERRORS } from 'ferda/HttpMixin'
import i18next from 'i18next'

import { URLS } from 'ferda_pain_js/Urls'
import { store } from 'ferda_pain_js/main.config'

import { PAIN_ACCESS_TOKEN } from '../constants'

import { get_axios_client } from './axios'

const login_user = async() => {
    const axios_client = get_axios_client()

    const response = await axios_client.get(
        URLS.pain_login_ajax(),
    )

    sessionStorage.setItem(PAIN_ACCESS_TOKEN, response.data?.token ?? '')
}

let login_promise = null
const handle_parallel_login = () => {
    login_promise = login_user().finally(() => {
        login_promise = null
    })
}

const refresh_pain_access_token = async() => {
    sessionStorage.removeItem(PAIN_ACCESS_TOKEN)
    if (login_promise === null) {
        handle_parallel_login()
    }
    await login_promise
}

export const use_pain_client = async(
    url,
    method,
    data = null,
    params = null,
    options = null,
    retry = true,
) => {
    const axios_client = get_axios_client()
    axios_client.defaults.baseURL = store.getters['pain_settings/PAIN_BASE_URL']
    axios_client.interceptors.request.use(
        async(config) => {
            const access_token = sessionStorage.getItem(PAIN_ACCESS_TOKEN)

            // Token missing completely, probably first attempt, we have to login
            if (!access_token) {
                await refresh_pain_access_token()
            }

            config.headers.Authorization = `Bearer ${ sessionStorage.getItem(PAIN_ACCESS_TOKEN) }`
            return config
        },
    )

    const request_url = params === null ? url : `${url}?${params.toString()}`

    try {
        return await axios_client({
            headers: {
                'Accept-Language': i18next.language,
            },
            ...(options ?? {}),
            url: request_url,
            method,
            data,
        })
    } catch (error) {
        if (retry && error.response?.status === 401) {
            await refresh_pain_access_token()
            return use_pain_client(url, method, data, params, options, false)
        }

        return {
            data: null,
            error: axios.isCancel(error) || error.name === HTTP_ERRORS.ABORT_ERROR ? HTTP_ERRORS.ABORT_ERROR : error,
        }
    }
}
