import { NotificationsMixin } from 'ferda/NotificationsMixin'

import { URLS } from 'ferda_pain_js/Urls'
import { use_pain_client } from 'ferda_pain_js/client/painClient'

/**
  * Requires bank_account_uid
  */
export default {
    mixins: [ NotificationsMixin ],
    data() {
        return {
            bank_account: {},
            is_loading_bank_account: false,
            is_deleting_bank_account: false,
        }
    },
    async mounted() {
        if (this.bank_account_uid) {
            await this.load_bank_account()
        }
    },
    watch: {
        bank_account_uid: {
            async handler(new_uid, old_uid) {
                if (new_uid === old_uid) {
                    return
                }

                if (!this.bank_account_uid) {
                    this.bank_account = {}
                    return
                }

                await this.load_bank_account()
            },
        },
    },
    methods: {
        notify_bank_account_not_found() {
            this.notify_message({
                title: this.$t('notifications:operation_failed'),
                text: this.$t('ferda_pain_bank_accounts:errors.not_found'),
                type: 'error',
                duration: -1,
            })
        },
        async load_bank_account() {
            this.is_loading_bank_account = true

            const {data, error} = await use_pain_client(
                URLS.pain_bank_account(this.bank_account_uid),
                'GET',
            )

            if (error && error.response?.status === 404) {
                this.notify_bank_account_not_found()
            } else if (error) {
                this.notify_message(this.ERROR_SOMETHING_WENT_WRONG)
            }

            this.bank_account = data ?? {}

            this.is_loading_bank_account = false

            return !error
        },
        async delete_bank_account() {
            this.is_deleting_bank_account = true

            const {error} = await use_pain_client(
                URLS.pain_bank_account(this.bank_account_uid),
                'DELETE',
            )

            if (error && error.response?.status === 404) {
                this.notify_bank_account_not_found()
            } else if (error && error.response?.status === 400) {
                this.notify_message({
                    title: this.$t('notifications:operation_failed'),
                    text: this.$t('ferda_pain_bank_accounts:errors.in_use'),
                    type: 'error',
                    duration: -1,
                })
            } else if (error) {
                this.notify_message(this.ERROR_SOMETHING_WENT_WRONG)
            } else {
                this.notify_message(this.SUCCESS_CHANGES_SAVED)
                this.bank_account = {}
            }

            this.is_deleting_bank_account = false

            return !error
        },
    },
}
