import { DatetimeMixin } from 'ferda/DatetimeMixin'

export default {
    mixins: [DatetimeMixin],
    methods: {
        format_date(date, format = 'll') {
            return date ? this.iso_to_moment(date).format(format) : '-'
        },
        format_price(price) {
            return (price === undefined || price === null || isNaN(price))
                ? '-'
                : new Intl.NumberFormat('cs-CZ', { style: 'currency', currency: 'CZK' }).format(price)
        },
        format_text(text) {
            return text ||  '-'
        },
        format_number(number) {
            if (number === undefined || number === null || isNaN(number)) return '-'

            const num = parseFloat(number)
            return Number.isInteger(num) ? num.toString() : num.toFixed(1)
        },
        format_rate(rate) {
            const rate_as_formatted_number = this.format_number(rate)
            return rate_as_formatted_number === '-' ? rate_as_formatted_number : rate_as_formatted_number + ' %'
        },
        format_customer(invoice) {
            if (invoice.name && invoice.organization) {
                return `${invoice.name}, ${invoice.organization}`
            } if (invoice.name) {
                return invoice.name
            } if (invoice.organization) {
                return invoice.organization
            }

            return invoice.customer_uid || '-'
        },
        format_bank_account(bank_account) {
            if (!bank_account.name) {
                return bank_account.number || '-'
            }

            return `${bank_account.name} ${bank_account.number}`
        },
    },
}
