import VueI18Next from '@panter/vue-i18next'
import { get_vuetify_options as get_ferda_vuetify_options } from 'FerdaJS/app.config'
import PageNotFound from 'ferda/common/PageNotFound.vue'
import i18next from 'i18next'
import Fetch from 'i18next-fetch-backend'
import LocalStorageBackend from 'i18next-localstorage-backend'
import Vue from 'vue'
import VueRouter from 'vue-router'
import Vuex, { Store as VuexStore } from 'vuex'
import YAML from 'yaml'

import { ICON_VALUES } from 'ferda_pain/icons'

import { get_i18next_ns_by_permissions } from './permissions'
import { PluginStore } from './store'

Vue.use(Vuex)
Vue.use(VueI18Next)
Vue.use(VueRouter)

// Setup default settings for router and extend them at module level
export const router = new VueRouter({ mode: 'history', routes: [{ path: '*', component: PageNotFound }] })

export const store = new VuexStore(PluginStore)

export const get_pain_vuetify_options = () => {
    const options = get_ferda_vuetify_options()
    options.icons.values = {
        ...options.icons.values,
        ...ICON_VALUES,
    }
    return options
}

/**
 * Get i18next options for Ferda Pain Module
 * @param {String} ferda_version
 * @param {String[]} permissions
 * @returns {Object} i18next options for Ferda PAIN module
 */
export const get_ferda_pain_i18next_options = (ferda_version, permissions) => {
    const ns = get_i18next_ns_by_permissions(permissions)

    return {
        lng: store.getters['preferences/selected_language'],
        fallbackLng: [store.getters['settings/LANGUAGE_CODE'], 'en'],
        ns,
        defaultNS: 'ferda_pain_common',
        backend: {
            backends: [LocalStorageBackend, Fetch],
            backendOptions: [
                {
                    versions: store.getters['settings/LANGUAGES'].reduce((language_versions, lang) => {
                        language_versions[lang] = ferda_version
                        return language_versions
                    }, {}),
                },
                {
                    loadPath: '/static/ferda_pain/locales/{{lng}}/{{ns}}.yml',
                    requestOptions: { cache: 'reload' },
                    parse: data => YAML.parse(data),
                },
            ],
        },
    }}

export const i18n = new VueI18Next(i18next)
