import 'vuetify/dist/vuetify.min.css'
import '@mdi/font/css/materialdesignicons.css'

import Notifications from '@remotehq/vue-notification'
import { i18n } from 'FerdaJS/app.config'
import i18next from 'i18next'
import Backend from 'i18next-chained-backend'
import Vue from 'vue'
import VueCookies from 'vue-cookies'
import Vuetify from 'vuetify/lib'

import {
    get_ferda_pain_i18next_options,
    get_pain_vuetify_options,
    store,
} from 'ferda_pain_js/main.config'

import PainBaseView from './components/PainBaseView.vue'
import router from './router'

Vue.use(VueCookies)
Vue.use(Vuetify)
Vue.use(Notifications)

// Listen for store changes from Ferda and sync them with the store here
document.addEventListener('storechange', event => {
    const { payload, type } = event.detail
    const value = payload.value ? payload.value : payload

    if (store._mutations[type]) {
        store.commit(type, value)
    }
})

const destination = document.currentScript.dataset.destination

document.addEventListener('ferda-loaded', async({ detail }) => {
    const permissions = detail.store_getters['general/permissions']
    const i18next_options = get_ferda_pain_i18next_options(detail.settings.django_settings.version, permissions)
    await i18next.use(Backend).init(i18next_options)
    store.commit('pain_settings/set_pain_base_url', detail.settings.django_settings.pain.api_url)

    if (destination === 'pain-module') {
        const options = get_pain_vuetify_options()
        const painEl = document.querySelector('#pain')
        if (painEl) {
            new Vue({
                el: '#pain',
                name: 'PainIndex',
                vuetify: new Vuetify(options),
                i18n,
                components: { PainBaseView },
                store,
                router,
                render: createElement => createElement(PainBaseView),
            })
        }
    }
})

window.addEventListener('popstate', () => {
    location.reload()
})

export { i18next }
