/**
 * Whether the user can view the PAIN module.
 * @param {String[]} permissions detail.store_getters['general/permissions']
 * @returns {Boolean} true if the user has permission can_view or can_maintain
 */
export const can_view_pain = (permissions) => {
    return permissions.some(permission =>
        permission === 'ferda_pain.can_view' || permission === 'ferda_pain.can_maintain',
    )
}

/**
 * Get the i18next namespaces based on the user's permissions.
 * @param {String[]} permissions detail.store_getters['general/permissions']
 * @returns {String[]} Array of i18next namespaces
 */
export const get_i18next_ns_by_permissions = (permissions) => {
    const ns = [
        'ferda_pain_common',
        'common', 'logger', 'login', 'notifications', 'rule',
    ]

    if (permissions.includes('ferda_pain.can_view')) {
        ns.push(
            'ferda_pain_bank_accounts',
            'ferda_pain_customers',
            'ferda_pain_invoices',
            'ferda_pain_bank_payments',
            'ferda_pain_payment_requests',
        )
    }

    if (permissions.includes('ferda_pain.can_maintain')) {
        ns.push('ferda_pain_vat_rates')
    }

    return ns
}
